% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lsm_c_cai_mn.R
\name{lsm_c_cai_mn}
\alias{lsm_c_cai_mn}
\title{CAI_MN (class level)}
\usage{
lsm_c_cai_mn(
  landscape,
  directions = 8,
  consider_boundary = FALSE,
  edge_depth = 1
)
}
\arguments{
\item{landscape}{A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.}

\item{directions}{The number of directions in which patches should be
connected: 4 (rook's case) or 8 (queen's case).}

\item{consider_boundary}{Logical if cells that only neighbour the landscape
boundary should be considered as core}

\item{edge_depth}{Distance (in cells) a cell has the be away from the patch
edge to be considered as core cell}
}
\value{
tibble
}
\description{
Mean of core area index (Core area metric)
}
\details{
\deqn{CAI_{MN} = mean(CAI[patch_{ij}]}
where \eqn{CAI[patch_{ij}]} is the core area index of each patch.

CAI_MN is a 'Core area metric'. The metric summarises each class
as the mean of the core area index of all patches belonging to class i.
The core area index is the percentage of core area in relation to patch area.
A cell is defined as core area if the cell has no neighbour with a different
value than itself (rook's case).

Because the metric is based on distances or areas please make sure your data
is valid using \code{\link{check_landscape}}.

\subsection{Units}{Percent}
\subsection{Range}{0 <= CAI_MN <= 100}
\subsection{Behaviour}{CAI_MN = 0 when all patches have no core area and
approaches CAI_MN = 100 with increasing percentage of core area within patches.}
}
\examples{
landscape <- terra::rast(landscapemetrics::landscape)
lsm_c_cai_mn(landscape)

}
\references{
McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
Program for Categorical Maps. Computer software program produced by the authors;
available at the following web site: https://www.fragstats.org
}
\seealso{
\code{\link{lsm_p_cai}},
\code{\link[base]{mean}}, \cr
\code{\link{lsm_c_cai_sd}},
\code{\link{lsm_c_cai_cv}}, \cr
\code{\link{lsm_l_cai_mn}},
\code{\link{lsm_l_cai_sd}},
\code{\link{lsm_l_cai_cv}}
}
